==> nextcloud-15.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/et_EE.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalender",
    "Todos" : "Ülesanded",
    "Personal" : "Isiklik",
    "{actor} created calendar {calendar}" : "{actor} lõi kalendri {calendar}",
    "You created calendar {calendar}" : "Sa lõid kalendri {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} kustutas kalendri {calendar}",
    "You deleted calendar {calendar}" : "Sa kustutasid kalendri {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} uuendas kalendrit {calendar}",
    "You updated calendar {calendar}" : "Sa uuendasid kalendrit {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} jagas kalendrit {calendar} sinuga",
    "You shared calendar {calendar} with {user}" : "Sa jagasid kalendrit {calendar} kasutajaga {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} jagas kalendrit {calendar} kasutajaga {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} lõpetas sinuga kalendri {calendar} jagamise",
    "You unshared calendar {calendar} from {user}" : "Sa lõpetasid kalendri {calendar} jagamise kasutajaga {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} lõpetas kalendri {calendar} jagamise kasutajaga {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} lõpetas iseendaga kalendri {calendar} jagamise",
    "You shared calendar {calendar} with group {group}" : "Sa jagasid kalendrit {calendar} grupiga {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} jagas kalendrit {calendar} grupiga {group}",
    "You unshared calendar {calendar} from group {group}" : "Sa lõpetasid kalendri {calendar} jagamise grupiga {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} lõpetas kalendri {calendar} jagamise grupiga {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} lõi sündmuse {event} kalendrisse {calendar}",
    "You created event {event} in calendar {calendar}" : "Sa lõid sündmuse {event} kalendrisse {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} kustutas sündmuse {event} kalendrist {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Sa kustutasid sündmuse {event} kalendrist {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} uuendas sündmust {event} kalendris {calendar}",
    "You updated event {event} in calendar {calendar}" : "Sa uuendasid sündmust {event} kalendris {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} lõi ülesande {todo} nimekirjas {calendar}",
    "You created todo {todo} in list {calendar}" : "Sa lõid ülesande {todo} nimekirjas {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} kustutas ülesande {todo} nimekirjast {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Sa kustutasid ülesande {todo} nimekirjast {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} uuendas ülesande {todo} nimekirjas {calendar}",
    "You updated todo {todo} in list {calendar}" : "Sa uuendasid ülesande {todo} nimekirjas {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} lõpetas ülesande {todo} nimekirjas {calendar}",
    "You solved todo {todo} in list {calendar}" : "Sa lõpetasid ülesande {todo} nimekirjas {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} taasavas ülesande {todo} nimekirjas {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Sa taasavasid ülesande {todo} nimekirjas {calendar}",
    "A <strong>calendar</strong> was modified" : " <strong>Kalendrit</strong> muudeti",
    "A calendar <strong>event</strong> was modified" : "Kalendri <strong>sündmust </strong> muudeti",
    "A calendar <strong>todo</strong> was modified" : "Kalendri <strong>ülesannet</strong> muudeti",
    "Contact birthdays" : "Kontaktide sünnipäevad",
    "Invitation canceled" : "Kutse on tühistatud",
    "Hello %s," : "Tere %s,",
    "Invitation updated" : "Kutse uuendatud",
    "When:" : "Millal:",
    "Where:" : "Kus:",
    "Description:" : "Kirjeldus:",
    "Link:" : "Link:",
    "Contacts" : "Kontaktid",
    "Technical details" : "Tehnilised detailid",
    "Remote Address: %s" : "Kaugaadress: %s",
    "Request ID: %s" : "Päringu ID: %s",
    "Send invitations to attendees" : "Saada osalejatele kutsed",
    "Please make sure to properly set up the email settings above." : "Veendu, et e-posti seaded oleksid eespool õigesti seadistatud.",
    "The meeting »%s« with %s was canceled." : "Koosolek »%s« osaleja(te)ga %s tühistati.",
    "The meeting »%s« with %s was updated." : "Koosolek »%s« osaleja(te)ga %s uuendati.",
    "%s invited you to »%s«" : "%s kutsus sind »%s«",
    "CalDAV server" : "CalDAV server"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-18.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/et_EE.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalender",
    "Todos" : "Ülesanded",
    "Personal" : "Isiklik",
    "{actor} created calendar {calendar}" : "{actor} lõi kalendri {calendar}",
    "You created calendar {calendar}" : "Sa lõid kalendri {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} kustutas kalendri {calendar}",
    "You deleted calendar {calendar}" : "Sa kustutasid kalendri {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} uuendas kalendrit {calendar}",
    "You updated calendar {calendar}" : "Sa uuendasid kalendrit {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} jagas kalendrit {calendar} sinuga",
    "You shared calendar {calendar} with {user}" : "Sa jagasid kalendrit {calendar} kasutajaga {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} jagas kalendrit {calendar} kasutajaga {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} lõpetas sinuga kalendri {calendar} jagamise",
    "You unshared calendar {calendar} from {user}" : "Sa lõpetasid kalendri {calendar} jagamise kasutajaga {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} lõpetas kalendri {calendar} jagamise kasutajaga {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} lõpetas iseendaga kalendri {calendar} jagamise",
    "You shared calendar {calendar} with group {group}" : "Sa jagasid kalendrit {calendar} grupiga {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} jagas kalendrit {calendar} grupiga {group}",
    "You unshared calendar {calendar} from group {group}" : "Sa lõpetasid kalendri {calendar} jagamise grupiga {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} lõpetas kalendri {calendar} jagamise grupiga {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} lõi sündmuse {event} kalendrisse {calendar}",
    "You created event {event} in calendar {calendar}" : "Sa lõid sündmuse {event} kalendrisse {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} kustutas sündmuse {event} kalendrist {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Sa kustutasid sündmuse {event} kalendrist {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} uuendas sündmust {event} kalendris {calendar}",
    "You updated event {event} in calendar {calendar}" : "Sa uuendasid sündmust {event} kalendris {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} lõi ülesande {todo} nimekirjas {calendar}",
    "You created todo {todo} in list {calendar}" : "Sa lõid ülesande {todo} nimekirjas {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} kustutas ülesande {todo} nimekirjast {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Sa kustutasid ülesande {todo} nimekirjast {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} uuendas ülesande {todo} nimekirjas {calendar}",
    "You updated todo {todo} in list {calendar}" : "Sa uuendasid ülesande {todo} nimekirjas {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} lõpetas ülesande {todo} nimekirjas {calendar}",
    "You solved todo {todo} in list {calendar}" : "Sa lõpetasid ülesande {todo} nimekirjas {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} taasavas ülesande {todo} nimekirjas {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Sa taasavasid ülesande {todo} nimekirjas {calendar}",
    "A <strong>calendar</strong> was modified" : " <strong>Kalendrit</strong> muudeti",
    "A calendar <strong>event</strong> was modified" : "Kalendri <strong>sündmust </strong> muudeti",
    "A calendar <strong>todo</strong> was modified" : "Kalendri <strong>ülesannet</strong> muudeti",
    "Contact birthdays" : "Kontaktide sünnipäevad",
    "Where:" : "Kus:",
    "Description:" : "Kirjeldus:",
    "Invitation canceled" : "Kutse on tühistatud",
    "Hello %s," : "Tere %s,",
    "Invitation updated" : "Kutse uuendatud",
    "When:" : "Millal:",
    "Link:" : "Link:",
    "Accept" : "Nõustu",
    "Decline" : "Keeldu",
    "Contacts" : "Kontaktid",
    "WebDAV" : "WebDAV",
    "Technical details" : "Tehnilised detailid",
    "Remote Address: %s" : "Kaugaadress: %s",
    "Request ID: %s" : "Päringu ID: %s",
    "Tentative" : "Esialgne",
    "Save" : "Salvesta",
    "Send invitations to attendees" : "Saada osalejatele kutsed",
    "Please make sure to properly set up the email settings above." : "Veendu, et e-posti seaded oleksid eespool õigesti seadistatud."
},
"nplurals=2; plural=(n != 1);");
